(* cgContext.mli     Wrapper for CGBitmapContext
 *
 * Copyright (c) 2011 Psellos   http://psellos.com
 * Licensed under the MIT license:
 *     http://www.opensource.org/licenses/mit-license.php
 *)
type t

(* Create a bitmap context that occupies a Raw array.  For this simple
 * example, all properties other than the size are fixed to reasonable
 * values, and only the width and height in pixels are specified.  The
 * returned context is in premultiplied `rgba format.
 *)
val create : int -> int -> t
val getData : t -> [`ubyte] Raw.t

(* Graphics state.
 *)
type linecap = LineCapButt | LineCapRound | LineCapSquare
val setLineCap : t -> linecap -> unit
val setLineWidth : t -> float -> unit

(* Bezier paths.
 *)
val addCurveToPoint : t -> Cocoa.point -> Cocoa.point -> Cocoa.point -> unit
val addLineToPoint : t -> Cocoa.point -> unit
val beginPath : t -> unit
val closePath : t -> unit
val moveToPoint : t -> Cocoa.point -> unit

(* Painting.
 *)
val fillPath : t -> unit
val fillRect : t -> Cocoa.rect -> unit
val strokePath : t -> unit

(* Setting colors.
 *)
val setFillColor : t -> Cocoa.color -> unit
val setStrokeColor : t -> Cocoa.color -> unit

(* Transforms.
 *)
val scaleCTM : t -> float -> float -> unit
val translateCTM : t -> float -> float -> unit

(* Text.
 *)
type tdmode =
    Fill | Stroke | FillStroke | Invisible |
    FillClip | StrokeClip | FillStrokeClip | Clip
type atm = float * float * float * float * float * float
val getTextPosition : t -> Cocoa.point
val selectFont : t -> string -> float -> unit
val setTextDrawingMode : t -> tdmode -> unit
val setTextMatrix : t -> atm -> unit
val setTextPosition : t -> Cocoa.point -> unit
val showText : t -> string -> int -> unit
