(* $Id: gl.mli,v 1.22 2007/04/13 01:17:50 garrigue Exp $ *)

(* Exceptions *)

exception GLerror of string

(* Types common to all modules *)

type rgb = float * float * float
type rgba = float * float * float * float

type point2 = float * float
type point3 = float * float * float
type point4 = float * float * float * float
type vect3 = float * float *float

type clampf = float
type short = int
type kind = [`bitmap|`byte|`float|`int|`short|`ubyte|`uint|`ushort]
type real_kind = [`byte|`float|`int|`short|`ubyte|`uint|`ushort]

type format =
  [`alpha|`luminance |`luminance_alpha|`rgb|`rgba|`bgra]
val format_size : [< format] -> int

type cmp_func =
  [`always|`equal|`gequal|`greater|`lequal|`less|`never|`notequal]
type face = [`back|`both|`front]

(* Basic functions *)

val flush : unit -> unit
val finish : unit -> unit

type cap =
  [`fog | `lighting | `texture_2d | `cull_face | `alpha_test | `blend
  |`color_logic_op | `dither | `stencil_test | `depth_test | `light0
  |`light1 | `light2 | `light3 | `light4 | `light5 | `light6 | `light7
  |`point_smooth | `line_smooth | `scissor_test | `color_material
  |`normalize | `rescale_normal | `polygon_offset_fill | `multisample
  |`sample_alpha_to_coverage | `sample_alpha_to_one | `sample_coverage ]

val enable : cap -> unit
val disable : cap -> unit
val is_enabled : cap -> bool

type error =
  [`no_error|`invalid_enum|`invalid_value|`invalid_operation
  |`stack_overflow|`stack_underflow|`out_of_memory]
val get_error : unit -> error
val raise_error : string -> unit
  (* raise GLerror if there is a current error, otherwise do nothing *)
