(** Vertex array manipulation functions *)
(* $Id: glArray.mli,v 1.7 2008/10/25 02:22:58 garrigue Exp $ *)

(** The different kinds for array *)
type kind =
  [`point_size | `texture_coord | `color | `normal | `vertex]
  
(** Tell openGL the address of the pointSize array
    Raw array must be static. *)
val pointsize : [ `float ] Raw.t -> unit

(** Tell openGL the address of the texCoor array
    Raw array must be static. *)
val tex_coord :
  [< `two | `three | `four] -> 
  [< `ubyte | `short | `float] Raw.t -> unit

(** Tell openGL the address of the color array
    Raw array must be static. *)
val color :
  [< `four] ->
  [< `ubyte | `float]
  Raw.t -> unit

(** Tell openGL the address of the normal array
    Raw array must be static. *)
val normal : [< `byte | `short | `float] Raw.t -> unit

(** Tell openGL the address of the vertex array
    Raw array must be static. *)
val vertex :
  [< `two | `three | `four] -> [< `byte | `short | `float] Raw.t
  -> unit

(** Tell openGL the address of to use the specified array
    Raw array must be static. *)
external enable : kind -> unit = "ml_glEnableClientState"

(** Tell openGL the address of not to use the specified array
   Raw array must be static. *)
external disable : kind -> unit = "ml_glDisableClientState"

(* GlArray.draw_arrays shape i c
   sends to openGL a GlDraw.begins shape and all the element from i to i+c-1 
   of all enabled arrays and finally do a GlDraw.ends () *)
external draw_arrays : GlDraw.shape -> first:int -> count:int -> unit
  = "ml_glDrawArrays"

(* GlArray.draw_elements shape c tbl
   sends to openGL a GlDraw.begins shape and all the element from tbl[0] to 
   tbl[c-1] of all enabled arrays and finally do a GlDraw.ends () *)
external draw_elements :
  GlDraw.shape -> count:int -> [< `ubyte | `uint | `ushort ] Raw.t -> unit
  = "ml_glDrawElements"
